@@ -6,7 +6,7 @@ use Ref::Util qw/:all/;
 use UNIVERSAL::Object;
 use Data::GUID;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use feature qw/switch/;
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
@@ -73,7 +73,7 @@ BEGIN {
                 is_hashref($val) && is_hashref( $_[1] )
                   and return
                   map { $_[0]->{$attr}->{$_} = $_[1]->{$_} } keys %{ $_[1] };
-                $_[0]->{$a} = $_[1] and return;
+                $_[0]->{$attr} = $_[1] and return;
               }
         };
     }
